@@ -71,9 +71,11 @@ def clone( repo ):
     runccore("git", "clone", "--bare", repo, "%s/.dotstrap" % os.environ["HOME"])
 
     if run( "checkout" ) != 0:
-        echo(click.style('could not checkout - did you specify a valid repo?', fg="red"))
+        echo(click.style('could not checkout - did you specify a valid repo? or maybe some files were in the way?', fg="red"))
         return
 
+    run( "config", "--local", "status.showUntrackedFiles", "no" )
+
     echo('cloning done')
 
 @click.command()
